as.yyww(x, format_check = TRUE)
as.yyyyww(x, format_check = TRUE)x be checked to be in correct
format before we try to change it? TRUE by default. Set to FALSE
if the format is already checked outside the function to avoid multiple checks
(that could be time consuming for big data sets).